========================================
``psyclone.domain.lfric.function_space``
========================================

.. automodule:: psyclone.domain.lfric.function_space

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.function_space
